@@ -1,26 +1,22 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2015 openpyxl
+# Copyright (c) 2010-2017 openpyxl
 
-from openpyxl.compat import safe_string
+from openpyxl.descriptors.serialisable import Serialisable
 from openpyxl.descriptors import (
-    Strict,
     Float,
-    Typed,
     Bool,
     Integer,
     String,
     NoneSet,
+    Alias,
     )
-from openpyxl.descriptors.excel import UniversalMeasure
-from openpyxl.xml.functions import Element
-from openpyxl.xml.constants import SHEET_MAIN_NS, REL_NS
-from openpyxl.compat import deprecated
+from openpyxl.descriptors.excel import UniversalMeasure, Relation
 
 
-class PageSetup(Strict):
-    """ Worksheet page setup """
+class PrintPageSetup(Serialisable):
+    """ Worksheet print page setup """
 
-    tag = "{%s}pageSetup" % SHEET_MAIN_NS
+    tagname = "pageSetup"
 
     orientation = NoneSet(values=("default", "portrait", "landscape"))
     paperSize = Integer(allow_none=True)
@@ -40,9 +36,12 @@ class PageSetup(Strict):
     horizontalDpi = Integer(allow_none=True)
     verticalDpi = Integer(allow_none=True)
     copies = Integer(allow_none=True)
-    id = String(allow_none=True)
+    id = Relation()
 
-    def __init__(self, orientation=None,
+
+    def __init__(self,
+                 worksheet=None,
+                 orientation=None,
                  paperSize=None,
                  scale=None,
                  fitToHeight=None,
@@ -61,6 +60,7 @@ class PageSetup(Strict):
                  verticalDpi=None,
                  copies=None,
                  id=None):
+        self._parent = worksheet
         self.orientation = orientation
         self.paperSize = paperSize
         self.scale = scale
@@ -81,49 +81,46 @@ class PageSetup(Strict):
         self.copies = copies
         self.id = id
 
-    @deprecated("this property does not exists anymore")
-    def setup(self):
-        pass
 
-    @deprecated("this property does not exists anymore")
-    def options(self):
-        pass
+    @property
+    def sheet_properties(self):
+        """
+        Proxy property
+        """
+        return self._parent.sheet_properties.pageSetUpPr
 
-    @deprecated("this property has to be called via print_options")
-    def horizontalCentered(self):
-        pass
 
-    @deprecated("this property has to be called via print_options")
-    def verticalCentered(self):
-        pass
-
-    @deprecated("this property has to be called via sheet_properties")
+    @property
     def fitToPage(self):
-        pass
-
-    def __iter__(self):
-        for attr in ("orientation", "paperSize", "scale", "fitToHeight",
-                     "fitToWidth", "firstPageNumber", "useFirstPageNumber" ,
-                     "paperHeight", "paperWidth", "pageOrder", "usePrinterDefaults",
-                     "blackAndWhite", "draft", "cellComments", "errors" , "horizontalDpi",
-                     "verticalDpi", "copies", "id"):
-            value = getattr(self, attr)
-            if value is not None:
-                yield attr, safe_string(value)
-
-    def write_xml_element(self):
-
-        attrs = dict(self)
-        if 'id' in attrs:
-            attrs['{%s}id' % REL_NS] = attrs['id']
-            del attrs['id']
-        return Element(self.tag, attrs)
+        return self.sheet_properties.fitToPage
 
 
-class PrintOptions(Strict):
+    @fitToPage.setter
+    def fitToPage(self, value):
+        self.sheet_properties.fitToPage = value
+
+
+    @property
+    def autoPageBreaks(self):
+        return self.sheet_properties.autoPageBreaks
+
+
+    @autoPageBreaks.setter
+    def autoPageBreaks(self, value):
+        self.sheet_properties.autoPageBreaks = value
+
+
+    @classmethod
+    def from_tree(cls, node):
+        self = super(PrintPageSetup, cls).from_tree(node)
+        self.id = None # strip link to binary settings
+        return self
+
+
+class PrintOptions(Serialisable):
     """ Worksheet print options """
 
-    tag = "{%s}printOptions" % SHEET_MAIN_NS
+    tagname = "printOptions"
     horizontalCentered = Bool(allow_none=True)
     verticalCentered = Bool(allow_none=True)
     headings = Bool(allow_none=True)
@@ -142,22 +139,8 @@ class PrintOptions(Strict):
         self.gridLines = gridLines
         self.gridLinesSet = gridLinesSet
 
-    def __iter__(self):
-        for attr in ("horizontalCentered", "verticalCentered", "headings",
-                     "gridLines", "gridLinesSet"):
-            value = getattr(self, attr)
-            if value is not None:
-                yield attr, safe_string(value)
 
-
-    def write_xml_element(self):
-
-        el = Element(self.tag, dict(self))
-
-        return el
-
-
-class PageMargins(Strict):
+class PageMargins(Serialisable):
     """
     Information about page margins for view/print layouts.
     Standard values (in inches)
@@ -165,6 +148,7 @@ class PageMargins(Strict):
     top, bottom = 1
     header, footer = 0.5
     """
+    tagname = "pageMargins"
 
     left = Float()
     right = Float()
@@ -181,8 +165,3 @@ class PageMargins(Strict):
         self.bottom = bottom
         self.header = header
         self.footer = footer
-
-    def __iter__(self):
-        for key in ("left", "right", "top", "bottom", "header", "footer"):
-            value = getattr(self, key)
-            yield key, safe_string(value)
